@@ -5,6 +5,7 @@
 # or https://github.com/scikit-hep/decaylanguage for details.
 
 import pytest
+import sys
 
 try:
     from pathlib2 import Path
@@ -13,8 +14,6 @@ except ImportError:
 
 from lark import Tree, Token
 
-from decaylanguage import data
-
 from decaylanguage.dec.dec import DecFileParser
 from decaylanguage.dec.dec import DecFileNotParsed, DecayNotFound
 from decaylanguage.dec.dec import DecayModelParamValueReplacement
@@ -26,10 +25,7 @@ from decaylanguage.dec.dec import get_model_parameters
 
 from decaylanguage.dec.enums import known_decay_models
 
-# New in Python 3
-try:
-    FileNotFoundError
-except NameError:
+if sys.version_info < (3,):
     FileNotFoundError = IOError
 
 
@@ -52,7 +48,10 @@ def test_constructor_multiple_files():
     p = DecFileParser(
         DIR / "../data/test_Xicc2XicPiPi.dec", DIR / "../data/test_Bc2BsPi_Bs2KK.dec"
     )
-    p.parse()
+
+    with pytest.warns(UserWarning) as record:
+        p.parse()
+    assert len(record) == 1
 
     assert len(p._dec_file_names) == 2
     assert p.number_of_decays == 7
@@ -75,7 +74,7 @@ Enddecay
 
 def test_unknown_decfile():
     with pytest.raises(FileNotFoundError):
-        p = DecFileParser("non-existent.dec")
+        DecFileParser("non-existent.dec")
 
 
 def test_non_parsed_decfile():
@@ -98,7 +97,7 @@ def test_default_grammar_loading():
 
 def test_explicit_grammar_loading():
     p = DecFileParser(DIR / "../data/test_example_Dst.dec")
-    p.load_grammar(DIR / "../../decaylanguage/data/decfile.lark")
+    p.load_grammar(DIR / "../../src/decaylanguage/data/decfile.lark")
 
     assert p.grammar_loaded is True
 
@@ -186,14 +185,14 @@ def test_global_photos_flag():
     p = DecFileParser(DIR / "../data/defs-aliases-chargeconj.dec")
     p.parse()
 
-    assert p.global_photos_flag() == True
+    assert p.global_photos_flag()
 
 
 def test_missing_global_photos_flag():
     p = DecFileParser(DIR / "../data/test_example_Dst.dec")
     p.parse()
 
-    assert p.global_photos_flag() == False
+    assert not p.global_photos_flag()
 
 
 def test_list_charge_conjugate_decays():
@@ -230,7 +229,9 @@ def test_with_missing_info():
     ``
     """
     p = DecFileParser(DIR / "../data/test_Xicc2XicPiPi.dec")
-    p.parse()
+    with pytest.warns(UserWarning) as record:
+        p.parse()
+    assert len(record) == 1
 
     # Decay of anti-Xi_cc-sig missing
     assert p.number_of_decays == 3
@@ -293,7 +294,11 @@ def test_decay_model_parsing_with_variable_defs():
 
 def test_duplicate_decay_definitions():
     p = DecFileParser(DIR / "../data/duplicate-decays.dec")
-    p.parse()
+
+    with pytest.warns(UserWarning) as w:
+        p.parse()
+
+    assert len(w) == 2
 
     assert p.number_of_decays == 2
 
@@ -322,7 +327,9 @@ def test_list_decay_modes_on_the_fly():
     on the fly from the non-CC. decay.
     """
     p = DecFileParser(DIR / "../data/test_Xicc2XicPiPi.dec")
-    p.parse()
+    with pytest.warns(UserWarning) as record:
+        p.parse()
+    assert len(record) == 1
 
     # Parsed directly from the dec file
     assert p.list_decay_modes("MyXic+") == [["p+", "K-", "pi+"]]
@@ -556,14 +563,14 @@ def test_creation_charge_conjugate_decays_in_decfile_without_CDecay_defs():
 
 
 def test_master_DECAYdotDEC_file():
-    p = DecFileParser(DIR / "../../decaylanguage/data/DECAY_LHCB.DEC")
+    p = DecFileParser(DIR / "../../src/decaylanguage/data/DECAY_LHCB.DEC")
     p.parse()
 
     assert p.number_of_decays == 506
 
 
 def test_BELLE2_decfile():
-    p = DecFileParser(DIR / "../../decaylanguage/data/DECAY_BELLE2.DEC")
+    p = DecFileParser(DIR / "../../src/decaylanguage/data/DECAY_BELLE2.DEC")
     p.parse()
 
     # Just check the dec file will parse since I do not know
@@ -578,7 +585,7 @@ def test_lark_file_model_list_consistency():
     to the user via
     'from decaylanguage.dec.enums import known_decay_models'.
     """
-    filename = str(DIR / "../../decaylanguage/data/decfile.lark")
+    filename = str(DIR / "../../src/decaylanguage/data/decfile.lark")
     with open(filename) as lark_file:
         lines = lark_file.readlines()
         for line in lines:
