@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Copyright (c) 2020, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
@@ -19,5 +20,5 @@ DIR = Path(__file__).parent.resolve()
 
 def test_issue_90():
     with pytest.raises(UnexpectedToken):
-        p = DecFileParser(DIR / '../data/test_issue90.dec')
+        p = DecFileParser(DIR / "../data/test_issue90.dec")
         p.parse()
